==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm5/lib/WebFieldPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescription } from "./WebFieldPipeArgsDescription";
/**
 * @hidden
 */
var WebFieldPipeArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFieldPipeArgsDescriptionMetadata, _super);
    function WebFieldPipeArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFieldPipeArgsDescriptionMetadata.b = function (a) {
        if (WebFieldPipeArgsDescriptionMetadata.a == null) {
            WebFieldPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFieldPipeArgsDescriptionMetadata.c(WebFieldPipeArgsDescriptionMetadata.a);
        }
        if (a.k(WebFieldPipeArgsDescriptionMetadata.a)) {
            return;
        }
        a.ab(WebFieldPipeArgsDescriptionMetadata.a);
    };
    WebFieldPipeArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FieldPipeArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Format", "String");
        a.item("Timezone", "String");
        a.item("DigitsInfo", "String");
        a.item("CurrencyCode", "String");
        a.item("Display", "String");
        a.item("WeekStart", "Number:double");
    };
    WebFieldPipeArgsDescriptionMetadata.d = function (a) {
        WebFieldPipeArgsDescriptionMetadata.b(a);
        a.ad("WebFieldPipeArgs", function () { return new WebFieldPipeArgsDescription(); });
        a.ac("WebFieldPipeArgs", WebFieldPipeArgsDescriptionMetadata.a);
    };
    WebFieldPipeArgsDescriptionMetadata.$t = markType(WebFieldPipeArgsDescriptionMetadata, 'WebFieldPipeArgsDescriptionMetadata');
    WebFieldPipeArgsDescriptionMetadata.a = null;
    return WebFieldPipeArgsDescriptionMetadata;
}(Base));
export { WebFieldPipeArgsDescriptionMetadata };

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm5/lib/WebFieldPipeArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldPipeArgsDescription } from "./WebFieldPipeArgsDescription";
/**
 * @hidden
 */
var WebFieldPipeArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebFieldPipeArgsDescriptionMetadata, _super);
    function WebFieldPipeArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebFieldPipeArgsDescriptionMetadata.b = function (a) {
        if (WebFieldPipeArgsDescriptionMetadata.a == null) {
            WebFieldPipeArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebFieldPipeArgsDescriptionMetadata.c(WebFieldPipeArgsDescriptionMetadata.a);
        }
        if (a.k(WebFieldPipeArgsDescriptionMetadata.a)) {
            return;
        }
        a.ac(WebFieldPipeArgsDescriptionMetadata.a);
    };
    WebFieldPipeArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:FieldPipeArgs");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("Format", "String");
        a.item("Timezone", "String");
        a.item("DigitsInfo", "String");
        a.item("CurrencyCode", "String");
        a.item("Display", "String");
        a.item("WeekStart", "Number:double");
    };
    WebFieldPipeArgsDescriptionMetadata.d = function (a) {
        WebFieldPipeArgsDescriptionMetadata.b(a);
        a.ae("WebFieldPipeArgs", function () { return new WebFieldPipeArgsDescription(); });
        a.ad("WebFieldPipeArgs", WebFieldPipeArgsDescriptionMetadata.a);
    };
    WebFieldPipeArgsDescriptionMetadata.$t = markType(WebFieldPipeArgsDescriptionMetadata, 'WebFieldPipeArgsDescriptionMetadata');
    WebFieldPipeArgsDescriptionMetadata.a = null;
    return WebFieldPipeArgsDescriptionMetadata;
}(Base));
export { WebFieldPipeArgsDescriptionMetadata };
